@@ -7,7 +7,7 @@
 
       CHARACTER CP*(*)
 
-      PARAMETER (NPARA = 120)
+      PARAMETER (NPARA = 121)
 
       INTEGER   ITYPE(NPARA)
       CHARACTER CPARAS(NPARA)*8
@@ -68,80 +68,81 @@
       DATA      CPARAS( 44)/'LARROW  '/, ITYPE( 44) / 2 /
       DATA      CPARAS( 45)/'LATONE  '/, ITYPE( 45) / 2 /
       DATA      CPARAS( 46)/'IATONE  '/, ITYPE( 46) / 1 /
-      DATA      CPARAS( 47)/'IWS     '/, ITYPE( 47) / 1 /
+      DATA      CPARAS( 47)/'IWS     '/, ITYPE( 47) / 0 /
       DATA      CPARAS( 48)/'ITR     '/, ITYPE( 48) / 1 /
-      DATA      CPARAS( 49)/'VXMIN   '/, ITYPE( 49) / 3 /
-      DATA      CPARAS( 50)/'VXMAX   '/, ITYPE( 50) / 3 /
-      DATA      CPARAS( 51)/'VYMIN   '/, ITYPE( 51) / 3 /
-      DATA      CPARAS( 52)/'VYMAX   '/, ITYPE( 52) / 3 /
-      DATA      CPARAS( 53)/'UXMIN   '/, ITYPE( 53) / 3 /
-      DATA      CPARAS( 54)/'UXMAX   '/, ITYPE( 54) / 3 /
-      DATA      CPARAS( 55)/'UYMIN   '/, ITYPE( 55) / 3 /
-      DATA      CPARAS( 56)/'UYMAX   '/, ITYPE( 56) / 3 /
-      DATA      CPARAS( 57)/'VXOFF   '/, ITYPE( 57) / 3 /
-      DATA      CPARAS( 58)/'VYOFF   '/, ITYPE( 58) / 3 /
-      DATA      CPARAS( 59)/'PLX     '/, ITYPE( 59) / 3 /
-      DATA      CPARAS( 60)/'PLY     '/, ITYPE( 60) / 3 /
-      DATA      CPARAS( 61)/'PLROT   '/, ITYPE( 61) / 3 /
-      DATA      CPARAS( 62)/'SIMFAC  '/, ITYPE( 62) / 3 /
-      DATA      CPARAS( 63)/'STLAT1  '/, ITYPE( 63) / 3 /
-      DATA      CPARAS( 64)/'STLAT2  '/, ITYPE( 64) / 3 /
-      DATA      CPARAS( 65)/'TXMIN   '/, ITYPE( 65) / 3 /
-      DATA      CPARAS( 66)/'TXMAX   '/, ITYPE( 66) / 3 /
-      DATA      CPARAS( 67)/'TYMIN   '/, ITYPE( 67) / 3 /
-      DATA      CPARAS( 68)/'TYMAX   '/, ITYPE( 68) / 3 /
-      DATA      CPARAS( 69)/'CXMIN   '/, ITYPE( 69) / 3 /
-      DATA      CPARAS( 70)/'CXMAX   '/, ITYPE( 70) / 3 /
-      DATA      CPARAS( 71)/'CYMIN   '/, ITYPE( 71) / 3 /
-      DATA      CPARAS( 72)/'CYMAX   '/, ITYPE( 72) / 3 /
-      DATA      CPARAS( 73)/'RSAT    '/, ITYPE( 73) / 3 /
-      DATA      CPARAS( 74)/'LDEG    '/, ITYPE( 74) / 2 /
-      DATA      CPARAS( 75)/'NFRAME  '/, ITYPE( 75) / 1 /
-      DATA      CPARAS( 76)/'NPAGE   '/, ITYPE( 76) / 1 /
-      DATA      CPARAS( 77)/'NLEVEL  '/, ITYPE( 77) / 1 /
-      DATA      CPARAS( 78)/'FACTOR  '/, ITYPE( 78) / 3 /
-      DATA      CPARAS( 79)/'INDEX   '/, ITYPE( 79) / 1 /
-      DATA      CPARAS( 80)/'LCORNER '/, ITYPE( 80) / 2 /
-      DATA      CPARAS( 81)/'LTITLE  '/, ITYPE( 81) / 2 /
-      DATA      CPARAS( 82)/'CORNER  '/, ITYPE( 82) / 3 /
-      DATA      CPARAS( 83)/'XPAD    '/, ITYPE( 83) / 3 /
-      DATA      CPARAS( 84)/'YPAD    '/, ITYPE( 84) / 3 /
-      DATA      CPARAS( 85)/'LWIDE   '/, ITYPE( 85) / 2 /
-      DATA      CPARAS( 86)/'ITR3    '/, ITYPE( 86) / 1 /
-      DATA      CPARAS( 87)/'TILT3   '/, ITYPE( 87) / 3 /
-      DATA      CPARAS( 88)/'ANGLE3  '/, ITYPE( 88) / 3 /
-      DATA      CPARAS( 89)/'XOFF3   '/, ITYPE( 89) / 3 /
-      DATA      CPARAS( 90)/'YOFF3   '/, ITYPE( 90) / 3 /
-      DATA      CPARAS( 91)/'XOBJ3   '/, ITYPE( 91) / 3 /
-      DATA      CPARAS( 92)/'YOBJ3   '/, ITYPE( 92) / 3 /
-      DATA      CPARAS( 93)/'ZOBJ3   '/, ITYPE( 93) / 3 /
-      DATA      CPARAS( 94)/'XEYE3   '/, ITYPE( 94) / 3 /
-      DATA      CPARAS( 95)/'YEYE3   '/, ITYPE( 95) / 3 /
-      DATA      CPARAS( 96)/'ZEYE3   '/, ITYPE( 96) / 3 /
-      DATA      CPARAS( 97)/'IXC3    '/, ITYPE( 97) / 1 /
-      DATA      CPARAS( 98)/'IYC3    '/, ITYPE( 98) / 1 /
-      DATA      CPARAS( 99)/'SEC3    '/, ITYPE( 99) / 3 /
-      DATA      CPARAS(100)/'LFGBG   '/, ITYPE(100) / 2 /
-      DATA      CPARAS(101)/'L2TO3   '/, ITYPE(101) / 2 /
-      DATA      CPARAS(102)/'VXMIN3  '/, ITYPE(102) / 3 /
-      DATA      CPARAS(103)/'VXMAX3  '/, ITYPE(103) / 3 /
-      DATA      CPARAS(104)/'VYMIN3  '/, ITYPE(104) / 3 /
-      DATA      CPARAS(105)/'VYMAX3  '/, ITYPE(105) / 3 /
-      DATA      CPARAS(106)/'VZMIN3  '/, ITYPE(106) / 3 /
-      DATA      CPARAS(107)/'VZMAX3  '/, ITYPE(107) / 3 /
-      DATA      CPARAS(108)/'UXMIN3  '/, ITYPE(108) / 3 /
-      DATA      CPARAS(109)/'UXMAX3  '/, ITYPE(109) / 3 /
-      DATA      CPARAS(110)/'UYMIN3  '/, ITYPE(110) / 3 /
-      DATA      CPARAS(111)/'UYMAX3  '/, ITYPE(111) / 3 /
-      DATA      CPARAS(112)/'UZMIN3  '/, ITYPE(112) / 3 /
-      DATA      CPARAS(113)/'UZMAX3  '/, ITYPE(113) / 3 /
-      DATA      CPARAS(114)/'VXORG3  '/, ITYPE(114) / 3 /
-      DATA      CPARAS(115)/'VYORG3  '/, ITYPE(115) / 3 /
-      DATA      CPARAS(116)/'VZORG3  '/, ITYPE(116) / 3 /
-      DATA      CPARAS(117)/'SIMFAC3 '/, ITYPE(117) / 3 /
-      DATA      CPARAS(118)/'LXLOG3  '/, ITYPE(118) / 2 /
-      DATA      CPARAS(119)/'LYLOG3  '/, ITYPE(119) / 2 /
-      DATA      CPARAS(120)/'LZLOG3  '/, ITYPE(120) / 2 /
+      DATA      CPARAS( 49)/'IBGCLI  '/, ITYPE( 49) / 1 /
+      DATA      CPARAS( 50)/'VXMIN   '/, ITYPE( 50) / 3 /
+      DATA      CPARAS( 51)/'VXMAX   '/, ITYPE( 51) / 3 /
+      DATA      CPARAS( 52)/'VYMIN   '/, ITYPE( 52) / 3 /
+      DATA      CPARAS( 53)/'VYMAX   '/, ITYPE( 53) / 3 /
+      DATA      CPARAS( 54)/'UXMIN   '/, ITYPE( 54) / 3 /
+      DATA      CPARAS( 55)/'UXMAX   '/, ITYPE( 55) / 3 /
+      DATA      CPARAS( 56)/'UYMIN   '/, ITYPE( 56) / 3 /
+      DATA      CPARAS( 57)/'UYMAX   '/, ITYPE( 57) / 3 /
+      DATA      CPARAS( 58)/'VXOFF   '/, ITYPE( 58) / 3 /
+      DATA      CPARAS( 59)/'VYOFF   '/, ITYPE( 59) / 3 /
+      DATA      CPARAS( 60)/'PLX     '/, ITYPE( 60) / 3 /
+      DATA      CPARAS( 61)/'PLY     '/, ITYPE( 61) / 3 /
+      DATA      CPARAS( 62)/'PLROT   '/, ITYPE( 62) / 3 /
+      DATA      CPARAS( 63)/'SIMFAC  '/, ITYPE( 63) / 3 /
+      DATA      CPARAS( 64)/'STLAT1  '/, ITYPE( 64) / 3 /
+      DATA      CPARAS( 65)/'STLAT2  '/, ITYPE( 65) / 3 /
+      DATA      CPARAS( 66)/'TXMIN   '/, ITYPE( 66) / 3 /
+      DATA      CPARAS( 67)/'TXMAX   '/, ITYPE( 67) / 3 /
+      DATA      CPARAS( 68)/'TYMIN   '/, ITYPE( 68) / 3 /
+      DATA      CPARAS( 69)/'TYMAX   '/, ITYPE( 69) / 3 /
+      DATA      CPARAS( 70)/'CXMIN   '/, ITYPE( 70) / 3 /
+      DATA      CPARAS( 71)/'CXMAX   '/, ITYPE( 71) / 3 /
+      DATA      CPARAS( 72)/'CYMIN   '/, ITYPE( 72) / 3 /
+      DATA      CPARAS( 73)/'CYMAX   '/, ITYPE( 73) / 3 /
+      DATA      CPARAS( 74)/'RSAT    '/, ITYPE( 74) / 3 /
+      DATA      CPARAS( 75)/'LDEG    '/, ITYPE( 75) / 2 /
+      DATA      CPARAS( 76)/'NFRAME  '/, ITYPE( 76) / 1 /
+      DATA      CPARAS( 77)/'NPAGE   '/, ITYPE( 77) / 1 /
+      DATA      CPARAS( 78)/'NLEVEL  '/, ITYPE( 78) / 1 /
+      DATA      CPARAS( 79)/'FACTOR  '/, ITYPE( 79) / 3 /
+      DATA      CPARAS( 80)/'INDEX   '/, ITYPE( 80) / 1 /
+      DATA      CPARAS( 81)/'LCORNER '/, ITYPE( 81) / 2 /
+      DATA      CPARAS( 82)/'LTITLE  '/, ITYPE( 82) / 2 /
+      DATA      CPARAS( 83)/'CORNER  '/, ITYPE( 83) / 3 /
+      DATA      CPARAS( 84)/'XPAD    '/, ITYPE( 84) / 3 /
+      DATA      CPARAS( 85)/'YPAD    '/, ITYPE( 85) / 3 /
+      DATA      CPARAS( 86)/'LWIDE   '/, ITYPE( 86) / 2 /
+      DATA      CPARAS( 87)/'ITR3    '/, ITYPE( 87) / 1 /
+      DATA      CPARAS( 88)/'TILT3   '/, ITYPE( 88) / 3 /
+      DATA      CPARAS( 89)/'ANGLE3  '/, ITYPE( 89) / 3 /
+      DATA      CPARAS( 90)/'XOFF3   '/, ITYPE( 90) / 3 /
+      DATA      CPARAS( 91)/'YOFF3   '/, ITYPE( 91) / 3 /
+      DATA      CPARAS( 92)/'XOBJ3   '/, ITYPE( 92) / 3 /
+      DATA      CPARAS( 93)/'YOBJ3   '/, ITYPE( 93) / 3 /
+      DATA      CPARAS( 94)/'ZOBJ3   '/, ITYPE( 94) / 3 /
+      DATA      CPARAS( 95)/'XEYE3   '/, ITYPE( 95) / 3 /
+      DATA      CPARAS( 96)/'YEYE3   '/, ITYPE( 96) / 3 /
+      DATA      CPARAS( 97)/'ZEYE3   '/, ITYPE( 97) / 3 /
+      DATA      CPARAS( 98)/'IXC3    '/, ITYPE( 98) / 1 /
+      DATA      CPARAS( 99)/'IYC3    '/, ITYPE( 99) / 1 /
+      DATA      CPARAS(100)/'SEC3    '/, ITYPE(100) / 3 /
+      DATA      CPARAS(101)/'LFGBG   '/, ITYPE(101) / 2 /
+      DATA      CPARAS(102)/'L2TO3   '/, ITYPE(102) / 2 /
+      DATA      CPARAS(103)/'VXMIN3  '/, ITYPE(103) / 3 /
+      DATA      CPARAS(104)/'VXMAX3  '/, ITYPE(104) / 3 /
+      DATA      CPARAS(105)/'VYMIN3  '/, ITYPE(105) / 3 /
+      DATA      CPARAS(106)/'VYMAX3  '/, ITYPE(106) / 3 /
+      DATA      CPARAS(107)/'VZMIN3  '/, ITYPE(107) / 3 /
+      DATA      CPARAS(108)/'VZMAX3  '/, ITYPE(108) / 3 /
+      DATA      CPARAS(109)/'UXMIN3  '/, ITYPE(109) / 3 /
+      DATA      CPARAS(110)/'UXMAX3  '/, ITYPE(110) / 3 /
+      DATA      CPARAS(111)/'UYMIN3  '/, ITYPE(111) / 3 /
+      DATA      CPARAS(112)/'UYMAX3  '/, ITYPE(112) / 3 /
+      DATA      CPARAS(113)/'UZMIN3  '/, ITYPE(113) / 3 /
+      DATA      CPARAS(114)/'UZMAX3  '/, ITYPE(114) / 3 /
+      DATA      CPARAS(115)/'VXORG3  '/, ITYPE(115) / 3 /
+      DATA      CPARAS(116)/'VYORG3  '/, ITYPE(116) / 3 /
+      DATA      CPARAS(117)/'VZORG3  '/, ITYPE(117) / 3 /
+      DATA      CPARAS(118)/'SIMFAC3 '/, ITYPE(118) / 3 /
+      DATA      CPARAS(119)/'LXLOG3  '/, ITYPE(119) / 2 /
+      DATA      CPARAS(120)/'LYLOG3  '/, ITYPE(120) / 2 /
+      DATA      CPARAS(121)/'LZLOG3  '/, ITYPE(121) / 2 /
 
 *     / LONG  NAME /
 
@@ -193,78 +194,79 @@
       DATA      CPARAL( 46) / 'ARROWHEAD_SHADE_PATTERN' /
       DATA      CPARAL( 47) / '++++IWS     ' /
       DATA      CPARAL( 48) / '++++ITR     ' /
-      DATA      CPARAL( 49) / '++++VXMIN   ' /
-      DATA      CPARAL( 50) / '++++VXMAX   ' /
-      DATA      CPARAL( 51) / '++++VYMIN   ' /
-      DATA      CPARAL( 52) / '++++VYMAX   ' /
-      DATA      CPARAL( 53) / '++++UXMIN   ' /
-      DATA      CPARAL( 54) / '++++UXMAX   ' /
-      DATA      CPARAL( 55) / '++++UYMIN   ' /
-      DATA      CPARAL( 56) / '++++UYMAX   ' /
-      DATA      CPARAL( 57) / '++++VXOFF   ' /
-      DATA      CPARAL( 58) / '++++VYOFF   ' /
-      DATA      CPARAL( 59) / '++++PLX     ' /
-      DATA      CPARAL( 60) / '++++PLY     ' /
-      DATA      CPARAL( 61) / '++++PLROT   ' /
-      DATA      CPARAL( 62) / '++++SIMFAC  ' /
-      DATA      CPARAL( 63) / '++++STLAT1  ' /
-      DATA      CPARAL( 64) / '++++STLAT2  ' /
-      DATA      CPARAL( 65) / '++++TXMIN   ' /
-      DATA      CPARAL( 66) / '++++TXMAX   ' /
-      DATA      CPARAL( 67) / '++++TYMIN   ' /
-      DATA      CPARAL( 68) / '++++TYMAX   ' /
-      DATA      CPARAL( 69) / '++++CXMIN   ' /
-      DATA      CPARAL( 70) / '++++CXMAX   ' /
-      DATA      CPARAL( 71) / '++++CYMIN   ' /
-      DATA      CPARAL( 72) / '++++CYMAX   ' /
-      DATA      CPARAL( 73) / 'SATELLITE_ALTITUDE' /
-      DATA      CPARAL( 74) / 'USE_DEGREE' /
-      DATA      CPARAL( 75) / '****NFRAME  ' /
-      DATA      CPARAL( 76) / '****NPAGE   ' /
-      DATA      CPARAL( 77) / '****NLEVEL  ' /
-      DATA      CPARAL( 78) / '****FACTOR  ' /
-      DATA      CPARAL( 79) / 'CORNERMARK_INDEX' /
-      DATA      CPARAL( 80) / 'DRAW_CORNERMARK' /
-      DATA      CPARAL( 81) / 'DRAW_PAGE_TITLE' /
-      DATA      CPARAL( 82) / 'CORNERMARK_LENGTH' /
-      DATA      CPARAL( 83) / '****XPAD    ' /
-      DATA      CPARAL( 84) / '****YPAD    ' /
-      DATA      CPARAL( 85) / '****LWIDE   ' /
-      DATA      CPARAL( 86) / '++++ITR3    ' /
-      DATA      CPARAL( 87) / '++++TILT3   ' /
-      DATA      CPARAL( 88) / '++++ANGLE3  ' /
-      DATA      CPARAL( 89) / '++++XOFF3   ' /
-      DATA      CPARAL( 90) / '++++YOFF3   ' /
-      DATA      CPARAL( 91) / '++++XOBJ3   ' /
-      DATA      CPARAL( 92) / '++++YOBJ3   ' /
-      DATA      CPARAL( 93) / '++++ZOBJ3   ' /
-      DATA      CPARAL( 94) / '++++XEYE3   ' /
-      DATA      CPARAL( 95) / '++++YEYE3   ' /
-      DATA      CPARAL( 96) / '++++ZEYE3   ' /
-      DATA      CPARAL( 97) / '++++IXC3    ' /
-      DATA      CPARAL( 98) / '++++IYC3    ' /
-      DATA      CPARAL( 99) / '++++SEC3    ' /
-      DATA      CPARAL(100) / '****LFGBG   ' /
-      DATA      CPARAL(101) / '****L2TO3   ' /
-      DATA      CPARAL(102) / '++++VXMIN3  ' /
-      DATA      CPARAL(103) / '++++VXMAX3  ' /
-      DATA      CPARAL(104) / '++++VYMIN3  ' /
-      DATA      CPARAL(105) / '++++VYMAX3  ' /
-      DATA      CPARAL(106) / '++++VZMIN3  ' /
-      DATA      CPARAL(107) / '++++VZMAX3  ' /
-      DATA      CPARAL(108) / '++++UXMIN3  ' /
-      DATA      CPARAL(109) / '++++UXMAX3  ' /
-      DATA      CPARAL(110) / '++++UYMIN3  ' /
-      DATA      CPARAL(111) / '++++UYMAX3  ' /
-      DATA      CPARAL(112) / '++++UZMIN3  ' /
-      DATA      CPARAL(113) / '++++UZMAX3  ' /
-      DATA      CPARAL(114) / '++++VXORG3  ' /
-      DATA      CPARAL(115) / '++++VYORG3  ' /
-      DATA      CPARAL(116) / '++++VZORG3  ' /
-      DATA      CPARAL(117) / '++++SIMFAC3 ' /
-      DATA      CPARAL(118) / '++++LXLOG3  ' /
-      DATA      CPARAL(119) / '++++LYLOG3  ' /
-      DATA      CPARAL(120) / '++++LZLOG3  ' /
+      DATA      CPARAL( 49) / 'BACKGROUND_COLOR_INDEX' /
+      DATA      CPARAL( 50) / '++++VXMIN   ' /
+      DATA      CPARAL( 51) / '++++VXMAX   ' /
+      DATA      CPARAL( 52) / '++++VYMIN   ' /
+      DATA      CPARAL( 53) / '++++VYMAX   ' /
+      DATA      CPARAL( 54) / '++++UXMIN   ' /
+      DATA      CPARAL( 55) / '++++UXMAX   ' /
+      DATA      CPARAL( 56) / '++++UYMIN   ' /
+      DATA      CPARAL( 57) / '++++UYMAX   ' /
+      DATA      CPARAL( 58) / '++++VXOFF   ' /
+      DATA      CPARAL( 59) / '++++VYOFF   ' /
+      DATA      CPARAL( 60) / '++++PLX     ' /
+      DATA      CPARAL( 61) / '++++PLY     ' /
+      DATA      CPARAL( 62) / '++++PLROT   ' /
+      DATA      CPARAL( 63) / '++++SIMFAC  ' /
+      DATA      CPARAL( 64) / '++++STLAT1  ' /
+      DATA      CPARAL( 65) / '++++STLAT2  ' /
+      DATA      CPARAL( 66) / '++++TXMIN   ' /
+      DATA      CPARAL( 67) / '++++TXMAX   ' /
+      DATA      CPARAL( 68) / '++++TYMIN   ' /
+      DATA      CPARAL( 69) / '++++TYMAX   ' /
+      DATA      CPARAL( 70) / '++++CXMIN   ' /
+      DATA      CPARAL( 71) / '++++CXMAX   ' /
+      DATA      CPARAL( 72) / '++++CYMIN   ' /
+      DATA      CPARAL( 73) / '++++CYMAX   ' /
+      DATA      CPARAL( 74) / 'SATELLITE_ALTITUDE' /
+      DATA      CPARAL( 75) / 'USE_DEGREE' /
+      DATA      CPARAL( 76) / '****NFRAME  ' /
+      DATA      CPARAL( 77) / '****NPAGE   ' /
+      DATA      CPARAL( 78) / '****NLEVEL  ' /
+      DATA      CPARAL( 79) / '****FACTOR  ' /
+      DATA      CPARAL( 80) / 'CORNERMARK_INDEX' /
+      DATA      CPARAL( 81) / 'DRAW_CORNERMARK' /
+      DATA      CPARAL( 82) / 'DRAW_PAGE_TITLE' /
+      DATA      CPARAL( 83) / 'CORNERMARK_LENGTH' /
+      DATA      CPARAL( 84) / '****XPAD    ' /
+      DATA      CPARAL( 85) / '****YPAD    ' /
+      DATA      CPARAL( 86) / '****LWIDE   ' /
+      DATA      CPARAL( 87) / '++++ITR3    ' /
+      DATA      CPARAL( 88) / '++++TILT3   ' /
+      DATA      CPARAL( 89) / '++++ANGLE3  ' /
+      DATA      CPARAL( 90) / '++++XOFF3   ' /
+      DATA      CPARAL( 91) / '++++YOFF3   ' /
+      DATA      CPARAL( 92) / '++++XOBJ3   ' /
+      DATA      CPARAL( 93) / '++++YOBJ3   ' /
+      DATA      CPARAL( 94) / '++++ZOBJ3   ' /
+      DATA      CPARAL( 95) / '++++XEYE3   ' /
+      DATA      CPARAL( 96) / '++++YEYE3   ' /
+      DATA      CPARAL( 97) / '++++ZEYE3   ' /
+      DATA      CPARAL( 98) / '++++IXC3    ' /
+      DATA      CPARAL( 99) / '++++IYC3    ' /
+      DATA      CPARAL(100) / '++++SEC3    ' /
+      DATA      CPARAL(101) / '****LFGBG   ' /
+      DATA      CPARAL(102) / '****L2TO3   ' /
+      DATA      CPARAL(103) / '++++VXMIN3  ' /
+      DATA      CPARAL(104) / '++++VXMAX3  ' /
+      DATA      CPARAL(105) / '++++VYMIN3  ' /
+      DATA      CPARAL(106) / '++++VYMAX3  ' /
+      DATA      CPARAL(107) / '++++VZMIN3  ' /
+      DATA      CPARAL(108) / '++++VZMAX3  ' /
+      DATA      CPARAL(109) / '++++UXMIN3  ' /
+      DATA      CPARAL(110) / '++++UXMAX3  ' /
+      DATA      CPARAL(111) / '++++UYMIN3  ' /
+      DATA      CPARAL(112) / '++++UYMAX3  ' /
+      DATA      CPARAL(113) / '++++UZMIN3  ' /
+      DATA      CPARAL(114) / '++++UZMAX3  ' /
+      DATA      CPARAL(115) / '++++VXORG3  ' /
+      DATA      CPARAL(116) / '++++VYORG3  ' /
+      DATA      CPARAL(117) / '++++VZORG3  ' /
+      DATA      CPARAL(118) / '++++SIMFAC3 ' /
+      DATA      CPARAL(119) / '++++LXLOG3  ' /
+      DATA      CPARAL(120) / '++++LYLOG3  ' /
+      DATA      CPARAL(121) / '++++LZLOG3  ' /
 
 
       NCP = NPARA
