@@ -48,7 +48,7 @@
         CALL SWCGET('FNAME  ', COUT  )
         CALL SWCGET('TITLE  ', CTTL  )
         CALL SWIGET('IDMPDGT ', IDMPDGT)
-
+        CALL SWIGET('IBGPAGE ',IBGPAGE)
         CALL SWCMLL
         CALL SWQFNM('CLRMAP ', CLRMAP)
         CALL GLCGET('DSPATH',  DSPATH)
@@ -91,13 +91,15 @@
         CALL SWCGET('CIMGFMT ', CIMGFMT)
         CALL SWRGET('RIMGCMP ', RIMGCMP)
 
+        CALL SWLGET('LSEP   ', LSEP  )
+
         CALL ZGDOPN(IWS, IWIDTH, IHEIGH, IPOSX, IPOSY, IDMPDGT,
+     +       IBGPAGE,
      +       LWAIT, LWAIT0, LWAIT1, LALT, LSTDOT,LKEY, LDUMP, LWND,
-     +       LFGBG,IFL,CIMGFMT, RIMGCMP, CLRMAP, CBTMAP, COUT,
+     +       LFGBG,LSEP,IFL,CIMGFMT, RIMGCMP, CLRMAP, CBTMAP, COUT,
      +       CTTL)
 
 *        CALL SWLGET('LCOLOR ', LCOLOR)
-*        CALL SWLGET('LSEP   ', LSEP  )
 *        CALL SWLGET('LPRINT ', LPRINT)
 *        CALL SWCGET('LPR    ', CLPR  )
 
