@@ -1,11 +1,11 @@
 *-----------------------------------------------------------------------
 *     UEGTLA
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE UEGTLA(XMIN,XMAX,DX)
 
-      LOGICAL   LBOUND
+      LOGICAL   LBOUND,LEPSL
       EXTERNAL  RGNGE,IRLE,IRGE
 
 
@@ -19,6 +19,10 @@
       CALL UEIGET('ICOLOR2 ',ICLR2 )
       CALL UELGET('LBOUND  ',LBOUND)
 
+      CALL GLLGET('LEPSL   ',LEPSL )
+
+      CALL GLLSET('LEPSL   ',.TRUE.)
+
       IF (DX.GT.0) THEN
         DZ=DX
       ELSE IF (DX.EQ.0) THEN
@@ -51,4 +55,6 @@
 
    10 CONTINUE
 
+      CALL GLLSET('LEPSL   ',LEPSL )
+
       END
